<template>
  <div class="visit-count" ref="chart"></div>
</template>

<script>
import * as echarts from "echarts"
import { countByMajor } from "@/api/screen.js"
export default {
  data() {
    return {
      option: {},
    }
  },
  mounted() {
    this.initChart()
  },
  methods: {
    async initChart() {
      let data = [

      ]
      const res = await countByMajor()
      let xAxis = []
      let yAxis = []
      if (res.code == 200) {
        var obj = res.result;
        data = res.result.map(item => {
          xAxis.push(item.m2)
          yAxis.push(item.sizes)
        })
      }
      let option = {
        grid: {
          // 让图表占满容器
          top: "12%",
          left: "15%",
          right: "10%",
          bottom: "15%",
        },
        tooltip: {
          show: true,
          formatter: function (data) {
            var val = obj.filter(res=>{
              if(data.value == res.sizes){
                return res
              }
            })
            if(val.length>0){
              var num = val[0].m3
              if(num=="平方千米"){
                num= " km²";
              }else  if(num=="平方米"){
                num= " m²";
              }else  if(num=="千米"){
                num= " km";
              }
               return  val[0].m2+":<br/>"+val[0].sizes+ num;
            }else{
              return data;
            }
          },
        },
        xAxis: {
          data: xAxis,
          axisLabel: {
            show: true,
            color: "#ffff",
          
          },
          axisTick: {
            show: false,
          },
          axisLine: {
            show: true,
            lineStyle: {
              color: "rgba(95, 180, 237, 0.32)",
            },
          },
        },
        yAxis: {
          axisLine: {
            show: false,
          },
          axisTick: {
            show: false,
          },
          axisLabel: {
            color: "#ffff",
          },
          // 分割线
          splitLine: {
            lineStyle: {
              color: "#5d7289",
              width: 1,
              type: "dashed",
            },
          },
        },
        series: [
          {
            // 顶部圆片
            type: "pictorialBar",
            animation: false,
            itemStyle: {
              color: "rgba(115, 240, 252, 1)",
            },
            symbolRepeat: false,
            symbolSize: [15, 8],
            symbolMargin: 1,
            z: 10,
            data: data,
            symbolPosition: "end",
            symbolOffset: [0, -4],
          },
          {
            // 底部圆片
            type: "pictorialBar",
            animation: false,

            itemStyle: {
              color: "rgba(50, 96, 225, 0.8)",
            },
            symbolRepeat: false,
            symbolSize: [15, 8],
            symbolMargin: 1,
            z: 10,
            data: data,
            symbolPosition: "start",
            symbolOffset: [0, 3],
          },
          {
            barWidth: 15,
            animation: false,

            type: "bar",
            label: {
              show: true,
              position: "top",
              textStyle: {
                color: "#ffff",
              },
            },
            itemStyle: {
              color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                { offset: 1, color: "rgba(82, 180, 249, 0.35)" },
                { offset: 0, color: "rgba(82, 180, 249, 1)" },
              ]),
            },
            data: yAxis,
          },
        ],
      }

      const chart = echarts.init(this.$refs.chart)

      chart.setOption(option)
      window.addEventListener("resize", function () {
        chart.resize()
      })
    },
  },
}
</script>

<style lang="less" scoped>
.visit-count {
  width: 100%;
  height: calc(100% - 30px);
}
</style>
